summaryrefslogtreecommitdiffstats
path: root/slv2/plugin.h
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2007-09-22 19:43:11 +0000
committerDavid Robillard <d@drobilla.net>2007-09-22 19:43:11 +0000
commit996f9015fe055ca63823110175593317ac20c80f (patch)
tree526d4bb1c4dd2ed8c5a05dcacabe78e1d000bd22 /slv2/plugin.h
parent106b0784b8c8347bbbebcedc421030effdc26fd0 (diff)
downloadlilv-996f9015fe055ca63823110175593317ac20c80f.tar.gz
lilv-996f9015fe055ca63823110175593317ac20c80f.tar.bz2
lilv-996f9015fe055ca63823110175593317ac20c80f.zip
LV2 UI extension updates.
LV2 GUI support in ingen. git-svn-id: http://svn.drobilla.net/lad/slv2@763 a436a847-0d15-0410-975c-d299462d15a1
Diffstat (limited to 'slv2/plugin.h')
-rw-r--r--slv2/plugin.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/slv2/plugin.h b/slv2/plugin.h
index ed45a90..224a450 100644
--- a/slv2/plugin.h
+++ b/slv2/plugin.h
@@ -342,30 +342,30 @@ slv2_plugin_get_port_by_symbol(SLV2Plugin plugin,
const char* symbol);
/** Get a list of all GUIs available for this plugin.
*
- * Note this returns the URI of the GUI, and not the path/URI to its shared
- * library, use slv2_plugin_gui_get_library_uri with the values returned
+ * Note this returns the URI of the UI, and not the path/URI to its shared
+ * library, use slv2_plugin_ui_get_library_uri with the values returned
* here for that.
*
* \param plugin The plugin to get the GUIs for.
*
* Time = Query
*/
SLV2Values
-slv2_plugin_get_guis(SLV2Plugin plugin);
+slv2_plugin_get_uis(SLV2Plugin plugin);
-/** Get the URI for a GUI library.
+/** Get the URI for a UI library.
*
* \param plugin The plugin that the GUI is for.
* \param gui A GUI identifier as returned by slv2_plugin_get_guis() (with type SLV2_VALUE_GUI).
*
* Time = Query
*/
SLV2Value
-slv2_plugin_get_gui_library_uri(SLV2Plugin plugin,
- SLV2Value gui);
+slv2_plugin_get_ui_library_uri(SLV2Plugin plugin,
+ SLV2Value ui);
/** @} */
@@ -342,30 +342,30 @@ slv2_plugin_get_port_by_symbol(SLV2Plugin plugin,
const char* symbol);
-/** Get a list of all GUIs available for this plugin.
+/** Get a list of all UIs available for this plugin.
*
@@ -342,30 +342,30 @@ slv2_plugin_get_port_by_symbol(SLV2Plugin plugin,
* here for that.
*
- * \param plugin The plugin to get the GUIs for.
+ * \param plugin The plugin to get the UIs for.
*
* Time = Query
@@ -342,30 +342,30 @@ slv2_plugin_get_port_by_symbol(SLV2Plugin plugin,
*
- * \param plugin The plugin that the GUI is for.
- * \param gui A GUI identifier as returned by slv2_plugin_get_guis() (with type SLV2_VALUE_GUI).
+ * \param plugin The plugin that the UI is for.
+ * \param ui A UI identifier as returned by slv2_plugin_get_uis() (with type SLV2_VALUE_UI).
*
* Time = Query